@@ -17,6 +17,23 @@ from .errors import SecurityError, ObjectRemovedError
 _INVALID_STR = punctuation.replace("_", "")
 _re_valid = re_compile(f"[{re_escape(_INVALID_STR)}]+")
 
+_SQLITE_KEYWORDS = {
+    "ABORT", "ACTION", "ADD", "AFTER", "ALL", "ALTER","ANALYZE","AND","AS",
+    "ASC","ATTACH","AUTOINCREMENT","BEFORE","BEGIN","BETWEEN","BY","CASCADE",
+    "CASE","CAST","CHECK","COLLATE","COLUMN","COMMIT","CONFLICT","CONSTRAINT",
+    "CREATE","CROSS","CURRENT_DATE","CURRENT_TIME","CURRENT_TIMESTAMP","DATABASE",
+    "DEFAULT","DEFERRABLE","DEFERRED","DELETE","DESC","DETACH","DISTINCT","DROP",
+    "EACH","ELSE","END","ESCAPE","EXCEPT","EXCLUSIVE","EXISTS","EXPLAIN","FAIL","FOR",
+    "FOREIGN","FROM","FULL","GLOB","GROUP","HAVING","IF","IGNORE","IMMEDIATE","IN",
+    "INDEX","INDEXED","INITIALLY","INNER","INSERT","INSTEAD","INTERSECT","INTO","IS",
+    "ISNULL","JOIN","KEY","LEFT","LIKE","LIMIT","MATCH","NATURAL","NO","NOT","NOTNULL",
+    "NULL","OF","OFFSET","ON","OR","ORDER","OUTER","PLAN","PRAGMA","PRIMARY","QUERY",
+    "RAISE","RECURSIVE","REFERENCES","REGEXP","REINDEX","RELEASE","RENAME","REPLACE",
+    "RESTRICT","RIGHT","ROLLBACK","ROW","SAVEPOINT","SELECT","SET","TABLE","TEMP","TEMPORARY",
+    "THEN","TO","TRANSACTION","TRIGGER","UNION","UNIQUE","UPDATE","USING","VACUUM","VALUES",
+    "VIEW","VIRTUAL","WHEN","WHERE","WITH","WITHOUT",
+}
+
 # I hate it when i can't import stuff
 
 
@@ -45,6 +62,14 @@ class NullObject:
     def __float__(self) -> float:
         return 0.0
 
+class Sentinel: # pylint: disable=too-few-public-methods
+    """A Sentinel value, has unique behavior for Table API and Model API.
+
+    Pre-defined value:
+        - Null, use this one if you're unsure if the data you pulled exists or not.
+            The query builder will remove it if it detects Null sentinel."""
+    def __repr__(self) -> str:
+        return "<Sentinel>"
 
 class Row(dict):
     """Attribute Dictionary"""
@@ -85,9 +110,12 @@ def matches(pattern: Pattern, value: str):
 
 
 def check_one(data: str):
-    """check one to check if a string contains illegal character"""
+    """check one to check if a string contains illegal character OR
+    if it is a reserved SQL keyword"""
     if matches(_re_valid, data) is True:
         raise SecurityError("Cannot parse unsafe data.")
+    if data.upper() in _SQLITE_KEYWORDS:
+        raise SecurityError(f'"{data}" is a reserved SQL keyword and cannot be used.')
     return data
 
 
@@ -150,6 +178,7 @@ def test_installed():
 
 
 null = NullObject()
+Null = Sentinel()
 AttrDict = Row
 
 
@@ -162,6 +191,7 @@ def get_type_from_mapping(type_: str, mapping: dict[str, str]) -> str:
 
 __all__ = [
     "null",
+    "Null",
     "future_class_var_isdefined",
     "WithCursor",
     "check_iter",
